@@ -27,6 +27,7 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 		impute_missingness_with_rf_impute = FALSE,
 		impute_missingness_with_x_j_bar_for_lm = TRUE,
 		mem_cache_for_speed = TRUE,
+		flush_indices_to_save_RAM = TRUE,
 		serialize = FALSE,
 		seed = NULL,
 		verbose = TRUE){
@@ -276,6 +277,7 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 	.jcall(java_bart_machine, "V", "setProbPrune", mh_prob_steps[2])
 	.jcall(java_bart_machine, "V", "setVerbose", verbose)
 	.jcall(java_bart_machine, "V", "setMemCacheForSpeed", mem_cache_for_speed)
+	.jcall(java_bart_machine, "V", "setFlushIndicesToSaveRAM", flush_indices_to_save_RAM)
 	
 	if (!is.null(seed)){
 		#set the seed in R
@@ -320,7 +322,11 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 	
 	#build the bart machine and let the user know what type of BART this is
 	if (verbose){
-		cat("Now building bartMachine for", pred_type, "...")
+		cat("Now building bartMachine for", pred_type)
+		if (pred_type == "classification"){
+			cat(" where \"", y_levels[1], "\" is considered the target level", sep = "")
+		}
+		cat("...")
 		if (length(cov_prior_vec) != 0){
 			cat("Covariate importance prior ON. ")
 		}
@@ -373,6 +379,7 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 			verbose = verbose,
 			serialize = serialize,
 			mem_cache_for_speed = mem_cache_for_speed,
+			flush_indices_to_save_RAM = flush_indices_to_save_RAM,
 			debug_log = debug_log,
 			seed = seed,
 			num_rand_samps_in_library = num_rand_samps_in_library
@@ -389,7 +396,7 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 		}
 		if (pred_type == "regression"){
 			y_hat_posterior_samples = 
-					t(sapply(.jcall(bart_machine$java_bart_machine, "[[D", "getGibbsSamplesForPrediction", .jarray(model_matrix_training_data, dispatch = TRUE), as.integer(num_cores)), .jevalArray))
+				.jcall(bart_machine$java_bart_machine, "[[D", "getGibbsSamplesForPrediction", .jarray(model_matrix_training_data, dispatch = TRUE), as.integer(num_cores), simplify = TRUE)
 			
 			#to get y_hat.. just take straight mean of posterior samples
 			y_hat_train = rowMeans(y_hat_posterior_samples)
@@ -402,7 +409,7 @@ build_bart_machine = function(X = NULL, y = NULL, Xy = NULL,
 			bart_machine$rmse_train = sqrt(bart_machine$L2_err_train / bart_machine$n)
 		} else if (pred_type == "classification"){
 			p_hat_posterior_samples = 
-					t(sapply(.jcall(bart_machine$java_bart_machine, "[[D", "getGibbsSamplesForPrediction", .jarray(model_matrix_training_data, dispatch = TRUE), as.integer(num_cores)), .jevalArray))
+				.jcall(bart_machine$java_bart_machine, "[[D", "getGibbsSamplesForPrediction", .jarray(model_matrix_training_data, dispatch = TRUE), as.integer(num_cores), simplify = TRUE)
 			
 			#to get y_hat.. just take straight mean of posterior samples
 			p_hat_train = rowMeans(p_hat_posterior_samples)
