@@ -6,7 +6,7 @@
   if (substr(jv, 1L, 2L) == "1.") {
 	  jvn = as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
 	  if (jvn < 1.7){
-	  	stop("Java 7 (at minimum) is needed for this package but is not available.")
+		  warning("Java 7 (at minimum) is needed for this package but is does not seem to be available. This message may be in error; apologies if it is.")
 	  }		
   }
   
@@ -22,4 +22,4 @@
 			"If you run out of memory, restart R, and use e.g.\n'options(java.parameters = \"-Xmx5g\")' for 5GB of RAM before you call\n'library(bartMachine)'.\n",
 			sep = "")
   )
-}
+}
\ No newline at end of file
